---
name: Bug report
about: Create a report to help us improve.
title: ''
labels: bug
assignees: smly

---

🚨NOTE: Only bug reports about code in this repository will be accepted. Any questions or bug reports about mjai.app should be made in [Discussions](https://github.com/smly/mjai.app/discussions).

---- ↓Template content↓ ----

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Additional context**
Add any other context about the problem here.
